@@ -1,9 +1,11 @@
 import os
 import json
 import click
+import subprocess
 from dotenv import load_dotenv
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery
-import subprocess
+from jnius import autoclass
+
 
 load_dotenv()
 
@@ -17,26 +19,24 @@ class Network3Medusa():
     def network3_medusa(self):
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
-        parsed_json = json.dumps(raw_json)
-        self.add_file_to_hedera(parsed_json)
+        self.add_file_to_hedera(raw_json)
         
     def py2output(self):
         self.output = subprocess.run(["python", "call_clid.py", self.command], capture_output=True)
 
-    def add_file_to_hedera(self, parsed_json):
+    def add_file_to_hedera(self, raw_json):
         client = Client.forTestnet()
         client.setOperator(OPERATOR_ID, OPERATOR_KEY)
         tran = FileCreateTransaction()
-        print(tran.setKeys(OPERATOR_KEY.getPublicKey()))
-        # resp = tran.setKeys(OPERATOR_KEY.getPublicKey()).setContents(parsed_json).setMaxTransactionFee(Hbar(2)).execute(client)
-        # print("nodeId: ",  resp.nodeId.toString())
-        # receipt = resp.getReceipt(client)
-        # fileId = receipt.fileId
-        # print("file: ",  fileId.toString())
-        # query = FileContentsQuery()
-        # contents = query.setFileId(fileId).execute(client)
-        # json_contents = json.loads(contents.toStringUtf8())
-        # print(json_contents)        
+        resp = tran.setKeys(OPERATOR_KEY.getPublicKey()).setContents(raw_json).setMaxTransactionFee(Hbar(2)).execute(client)
+        print("nodeId: ",  resp.nodeId.toString())
+        receipt = resp.getReceipt(client)
+        fileId = receipt.fileId
+        print("file: ",  fileId.toString())
+        query = FileContentsQuery()
+        contents = query.setFileId(fileId).execute(client)
+        json_contents = json.loads(contents.toStringUtf8())
+        print(json_contents)        
 
 @click.command()
 @click.option('--command',
